<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Scanners

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Scanners` namespace.

This package provides the `winrt.windows.devices.scanners` module.
